import pkg_resources

SECRET_KEY = 'x'
USE_I18N = True
ROOT_URLCONF = 'testproject.urls'
INSTALLED_APPS = [
    'enmerkar',
    'testproject',
]
MIDDLEWARE = [
    'django.middleware.locale.LocaleMiddleware',
    'enmerkar.middleware.LocaleMiddleware',
]
MIDDLEWARE_CLASSES = MIDDLEWARE  # backwards compat
TEMPLATES = [
    {
        'NAME': 'default',
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.i18n',
            ],
        },
    },
]
LOCALE_PATHS = [
    pkg_resources.resource_filename(__name__, 'locale'),
]



from django.conf import settings

from testproject import settings as testproject_settings


def pytest_configure():
    filtered_settings = {k: v for (k, v) in vars(testproject_settings).items()
                         if k.isupper()}
    settings.configure(**filtered_settings)



# -- encoding: utf-8 --
from __future__ import unicode_literals

import pytest


@pytest.mark.parametrize('locale', ('en', 'fi', 'sv', 'pt-BR'))
def test_babel_render(client, locale):
    """
    Test the middleware and the rendery bits.
    """
    response = client.get('/', HTTP_ACCEPT_LANGUAGE=locale)
    # "Parse" the key-value format
    lines = response.content.decode('utf-8').strip().splitlines()
    content = dict(kv.split('=', 1) for kv in lines)
    # See that we're rendering in the locale we expect
    assert content['language_code'] == locale.lower()
    # check that we could access `babel.Locale.language_name`
    assert content['language_name'] == {
        'en': 'English',
        'fi': 'suomi',
        'sv': 'svenska',
        'pt-BR': 'português',
    }[locale]
    # The rest are not really tested (aside from smoke tests) further;
    # the Babel test suite has taken care of that.



import os

import pkg_resources
from django.core.management import call_command

TEST_LOCALE_DIR = pkg_resources.resource_filename(
    'testproject', 'locale'
)


def test_babel_compilemessages():
    call_command(
        'babel',
        'compilemessages',
        '-l', 'fi',
    )
    # Assert that the .mo file was created by attempting to delete it.
    os.unlink(
        os.path.join(TEST_LOCALE_DIR, 'fi', 'LC_MESSAGES', 'django.mo')
    )


def test_babel_makemessages():
    call_command(
        'babel',
        'makemessages',
        '-l', 'en',
        '-F', pkg_resources.resource_filename(__name__, 'babel.cfg'),
    )
    # See that the expected files get populated with the discovered message
    for path in [
        os.path.join(TEST_LOCALE_DIR, 'django.pot'),
        os.path.join(TEST_LOCALE_DIR, 'en', 'LC_MESSAGES', 'django.po'),
    ]:
        with open(path) as infp:
            assert '"This could be translated."' in infp.read()
        os.unlink(path)  # clean up



import time

from django.conf.urls import url
from django.shortcuts import render
from django.utils.timezone import now


def test_view(request):
    return render(request, 'test.txt', {
        'date': now(),
        'number': time.time(),
        'locale': request.locale,
    })


urlpatterns = [
    url('^$', test_view),
]
